package com.recordingblogs.oreffect;

import java.util.EventObject;

/**
 An undo event (an object from this class) will normally be fired by an effect when 
 there is a change to the effect parameters.  The UndoEvent object contains a 
 reference to the source (the effect object) and a string that contains the title of 
 the undo message.  The title of the undo message will simply be used for the Undo 
 application menu and so it will have the format "Undo Some Action/Property".

 You can redistribute this file, modify it, adapt it, translate it, and/or distribute 
 the modified version, whether free of charge or not.  This file is distributed as is, without 
 warranty of any kind.
  
 @author      Anton Kamenov
 @version     3.0
*/

public class UndoEvent extends EventObject 
{
	/**
	 * The serialVersionUID is not used as Orinj implements its own serialization
	 * @since 3.0
	 */
	static final long serialVersionUID = 2103748748628495846L;

	/**
	 * The undo message has the format "Undo Some Action/Property" (e.g.,
	 * Undo Delay Amounts) and is used for the Undo application menu item
	 * @since 3.0
	 */
	private String m_undoMessage;

	/**
	 * The default and only constructor
	 * @param source  The object firing this event.  This would normally be
	 *                the effect
	 * @param undoMessage  The undo message to be used for the application
	 * 					   undo menu item (e.g., "Undo Delay Amount")
	 * @since 3.0
	 */
	public UndoEvent(Object source, String undoMessage)
	{
		super(source);
		m_undoMessage = undoMessage;
	}
	
	/**
	 * Allow public access to the undo message
	 * @return  The undo message
	 * @since 3.0
	 */
	public String getUndoMessage()
	{
		return m_undoMessage;
	}
}
