package com.recordingblogs.oreffect;

import java.io.IOException;

/**
This interface is implemented by two classes in Orinj.  One of the classes is an
extension of java.io.ObjectOutputStream.  This class is used by Orinj for the serialization
(writing) of sessions, loops, and other objects.  The second class is a custom Orinj class
used to read undo information that was saved before, when the users click on undo menu
commands.  Having these two classes extend the same interface allows Orinj to use the 
same functions for reading for serialization and for reading for undo (see the function
writeObject in EffectInterface).  Note that the functions below largely match the 
member functions of java.io.ObjectOutputStream.

You do not need to implement this interface.  However, when implementing EffectInterface, 
specifically the function writeObject, the functions below are the only ones you can use
to write effect member data. 

You can redistribute this file, modify it, adapt it, translate it, and/or distribute 
the modified version, whether free of charge or not.  This file is distributed as is, without 
warranty of any kind.

@author      Anton Kamenov
@version     3.0
*/

public interface WriteInterface 
{
	/**
	 * Write a boolean
	 * @param value The boolean to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void writeBoolean(boolean value) throws IOException;
	
	/**
	 * Write a byte
	 * @param value The byte to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void writeByte(int value) throws IOException;
	
	/**
	 * Write a short
	 * @param value The short to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void writeShort(int value) throws IOException;
	
	/**
	 * Write an integer
	 * @param value The integer to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void writeInt(int value) throws IOException;
	
	/**
	 * Write a long
	 * @param value The long to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void writeLong(long value) throws IOException;
	
	/**
	 * Write a float
	 * @param value The float to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void writeFloat(float value) throws IOException;
	
	/**
	 * Write a double
	 * @param value The double to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void writeDouble(double value) throws IOException;
	
	/**
	 * Write a string
	 * @param value The string to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void writeString(String value) throws IOException;
	
	/**
	 * Write a byte array
	 * @param value The byte array to be written
	 * @throws IOException
	 * @since 3.0
	 */
	public void write(byte [] value) throws IOException;
}
